@@ -27,15 +27,14 @@
 #include <klocale.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
-#include <k3staticdeleter.h>
 #include <kconfiggroup.h>
 
+ #include <QCoreApplication>
+
 #include <stdlib.h>
 
 using namespace KABC;
 
-static K3StaticDeleter<StdAddressBook> addressBookDeleter;
-
 class StdAddressBook::Private
 {
   public:
@@ -48,13 +47,20 @@ class StdAddressBook::Private
     bool saveAll();
 
     StdAddressBook *mParent;
-    static StdAddressBook *mSelf;
     static bool mAutomaticSave;
 };
 
-StdAddressBook *StdAddressBook::Private::mSelf = 0;
+static StdAddressBook *s_gStdAddressBook = 0;
 bool StdAddressBook::Private::mAutomaticSave = true;
 
+static void deleteGlobalStdAddressBook()
+{
+  if ( s_gStdAddressBook ) {
+    delete s_gStdAddressBook;
+    s_gStdAddressBook = 0;
+  }
+}
+
 QString StdAddressBook::fileName()
 {
   return KStandardDirs::locateLocal( "data", "kabc/std.vcf" );
@@ -67,30 +73,43 @@ QString StdAddressBook::directoryName()
 
 StdAddressBook *StdAddressBook::self()
 {
-  kDebug(5700) << "StdAddressBook::self()";
+  kDebug();
 
-  if ( !Private::mSelf ) {
-    addressBookDeleter.setObject( Private::mSelf, new StdAddressBook );
-  }
-
-  return Private::mSelf;
+  // delegate to other self() method since the only difference
+  // was the constructor being used and their only difference is
+  // what they pass to Private::init()
+  return self( false );
 }
 
 StdAddressBook *StdAddressBook::self( bool asynchronous )
 {
-  kDebug(5700) << "StdAddressBook::self()";
+  kDebug() << "asynchronous=" << asynchronous;
 
-  if ( !Private::mSelf ) {
-    addressBookDeleter.setObject( Private::mSelf, new StdAddressBook( asynchronous ) );
+  if ( !s_gStdAddressBook ) {
+    s_gStdAddressBook = new StdAddressBook( asynchronous, false );
+
+    kDebug() << "calling init after instance creation";
+    s_gStdAddressBook->d->init( asynchronous );
+
+    // We don't use a global static here for this reason:
+    //
+    // There are problems with the destruction order: The destructor of
+    // StdAddressBook calls save(), which for LDAP address books, needs KIO
+    // (more specific: KProtocolInfo) to be still alive. However, with a global
+    // static, KProtocolInfo is already deleted, and the app will crash.
+    //
+    // qAddPostRoutine deletes the objects when the QApplication is destroyed,
+    // which is earlier than the global statics, so this will work.
+    qAddPostRoutine( deleteGlobalStdAddressBook );
   }
 
-  return Private::mSelf;
+  return s_gStdAddressBook;
 }
 
 StdAddressBook::StdAddressBook()
   : AddressBook( "" ), d( new Private( this ) )
 {
-  kDebug(5700) << "StdAddressBook::StdAddressBook()";
+  kDebug();
 
   d->init( false );
 }
@@ -98,11 +117,20 @@ StdAddressBook::StdAddressBook()
 StdAddressBook::StdAddressBook( bool asynchronous )
   : AddressBook( "" ), d( new Private( this ) )
 {
-  kDebug(5700) << "StdAddressBook::StdAddressBook( bool )";
+  kDebug();
 
   d->init( asynchronous );
 }
 
+StdAddressBook::StdAddressBook( bool asynchronous, bool doInit )
+  : AddressBook( "" ), d( new Private( this ) )
+{
+  kDebug();
+
+  if ( doInit )
+    d->init( asynchronous );
+}
+
 StdAddressBook::~StdAddressBook()
 {
   if ( Private::mAutomaticSave ) {
@@ -140,7 +168,7 @@ void StdAddressBook::Private::init( bool asynchronous )
     if ( res ) {
       mParent->addResource( res );
     } else {
-      kDebug(5700) << "No resource available!!!";
+      kDebug() << "No resource available!!!";
     }
   }
 
@@ -156,7 +184,7 @@ void StdAddressBook::Private::init( bool asynchronous )
 
 bool StdAddressBook::Private::saveAll()
 {
-  kDebug(5700) << "StdAddressBook::saveAll()";
+  kDebug();
   bool ok = true;
 
   KRES::Manager<Resource>::ActiveIterator it;
@@ -182,10 +210,10 @@ bool StdAddressBook::Private::saveAll()
 
 bool StdAddressBook::save()
 {
-  kDebug(5700) << "StdAddressBook::save()";
+  kDebug();
 
-  if ( Private::mSelf ) {
-    return Private::mSelf->d->saveAll();
+  if ( s_gStdAddressBook ) {
+    return s_gStdAddressBook->d->saveAll();
   } else {
     return true;
   }
@@ -193,7 +221,8 @@ bool StdAddressBook::save()
 
 void StdAddressBook::close()
 {
-  addressBookDeleter.destructObject();
+  delete s_gStdAddressBook;
+  s_gStdAddressBook = 0;
 }
 
 void StdAddressBook::setAutomaticSave( bool enable )
