@@ -371,7 +371,7 @@ public:
       /** Status of a successfully removed post.
       @see Blog::removePost( KBlog::BlogPost* ) */
       Removed,
-      /** Status when an error on the server side occured.
+      /** Status when an error on the server side occurred.
       @see error() */
       Error
     };
@@ -419,7 +419,7 @@ public:
     void swap( BlogPost &other ) { qSwap( this->d_ptr, other.d_ptr ); }
 
   private:
-    BlogPostPrivate *d_ptr;
+    BlogPostPrivate *d_ptr;  //krazy:exclude=dpointer can't constify due to bic and swap being declared inline
 };
 
 } //namespace KBlog
