@@ -82,13 +82,20 @@ Event *Event::clone()
   return new Event( *this );
 }
 
-bool Event::operator==( const Event &other ) const
+Event &Event::operator=( const Event &other )
+{
+  Incidence::operator=( other );
+  *d = *other.d;
+  return *this;
+}
+
+bool Event::operator==( const Event &event ) const
 {
   return
-    static_cast<const Incidence &>( *this ) == static_cast<const Incidence &>( other ) &&
-    dtEnd() == other.dtEnd() &&
-    hasEndDate() == other.hasEndDate() &&
-    transparency() == other.transparency();
+    static_cast<const Incidence &>( *this ) == static_cast<const Incidence &>( event ) &&
+    dtEnd() == event.dtEnd() &&
+    hasEndDate() == event.hasEndDate() &&
+    transparency() == event.transparency();
 }
 
 QByteArray Event::type() const
@@ -118,8 +125,8 @@ KDateTime Event::dtEnd() const
     return duration().end( dtStart() );
   }
 
-  kDebug(5800) << "Warning! Event '" << summary()
-               << "' has neither end date nor duration.";
+  kDebug() << "Warning! Event '" << summary()
+           << "' has neither end date nor duration.";
   return dtStart();
 }
 
@@ -171,6 +178,10 @@ QString Event::dtEndDateStr( bool shortfmt, const KDateTime::Spec &spec ) const
 
 QString Event::dtEndStr( bool shortfmt, const KDateTime::Spec &spec ) const
 {
+  if ( allDay() ) {
+    return dtEndDateStr( shortfmt, spec );
+  }
+
   if ( spec.isValid() ) {
 
     QString timeZone;
