@@ -17,7 +17,7 @@
   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  Boston, MA 02110-1301, USA.
 */
 /**
   @file
@@ -42,34 +42,62 @@
 using namespace KCal;
 
 //@cond PRIVATE
-class FreeBusy::Private
+class KCal::FreeBusy::Private
 {
   public:
+    Private()
+      : mCalendar( 0 )
+    {}
+
+    Private( const KCal::FreeBusy::Private &other )
+    { init( other ); }
+
+    Private( const FreeBusyPeriod::List &busyPeriods )
+      : mBusyPeriods( busyPeriods ),
+        mCalendar( 0 )
+    {}
+
+    void init( const KCal::FreeBusy::Private &other );
+
+    KDateTime mDtEnd;         // end datetime
+    FreeBusyPeriod::List mBusyPeriods;// list of periods
+    Calendar *mCalendar;      // associated calendar, not owned by this instance
+
     //This is used for creating a freebusy object for the current user
     bool addLocalPeriod( FreeBusy *fb, const KDateTime &start, const KDateTime &end );
-    KDateTime mDtEnd;
-    Period::List mBusyPeriods;
-    Calendar *mCalendar;    // not owned by this instance
 };
+
+void KCal::FreeBusy::Private::init( const KCal::FreeBusy::Private &other )
+{
+  mDtEnd = other.mDtEnd;
+  mBusyPeriods = other.mBusyPeriods;
+  mCalendar = other.mCalendar;
+}
+
 //@endcond
 
 FreeBusy::FreeBusy()
-  : d( new Private )
+  : d( new KCal::FreeBusy::Private() )
+{
+}
+
+FreeBusy::FreeBusy( const FreeBusy &other )
+  : IncidenceBase( other ),
+    d( new KCal::FreeBusy::Private( *other.d ) )
 {
 }
 
 FreeBusy::FreeBusy( const KDateTime &start, const KDateTime &end )
-  : d( new Private )
+  : d( new KCal::FreeBusy::Private() )
 {
   setDtStart( start );
   setDtEnd( end );
 }
 
-FreeBusy::FreeBusy( Calendar *calendar, const KDateTime &start,
-                    const KDateTime &end )
-  : d( new Private )
+FreeBusy::FreeBusy( Calendar *calendar, const KDateTime &start, const KDateTime &end )
+  : d( new KCal::FreeBusy::Private() )
 {
-  kDebug(5800) << "FreeBusy::FreeBusy";
+  kDebug();
   d->mCalendar = calendar;
 
   setDtStart( start );
@@ -96,7 +124,7 @@ FreeBusy::FreeBusy( Calendar *calendar, const KDateTime &start,
     Event *allDayEvent = 0;
     if ( event->allDay() ) {
       // addDay event. Do the hack
-      kDebug(5800) << "All-day event";
+      kDebug() << "All-day event";
       allDayEvent = new Event( *event );
 
       // Set the start and end times to be on midnight
@@ -108,7 +136,7 @@ FreeBusy::FreeBusy( Calendar *calendar, const KDateTime &start,
       allDayEvent->setDtStart( st );
       allDayEvent->setDtEnd( nd );
 
-      kDebug(5800) << "Use:" << st.toString() << "to" << nd.toString();
+      kDebug() << "Use:" << st.toString() << "to" << nd.toString();
       // Finally, use this event for the setting below
       event = allDayEvent;
     }
@@ -163,9 +191,14 @@ FreeBusy::FreeBusy( Calendar *calendar, const KDateTime &start,
 }
 
 FreeBusy::FreeBusy( const Period::List &busyPeriods )
-  : d( new Private )
+  : d( new KCal::FreeBusy::Private() )
+{
+  addPeriods(busyPeriods);
+}
+
+FreeBusy::FreeBusy( const FreeBusyPeriod::List &busyPeriods )
+  : d( new KCal::FreeBusy::Private( busyPeriods ) )
 {
-  d->mBusyPeriods = busyPeriods;
 }
 
 FreeBusy::~FreeBusy()
@@ -195,6 +228,17 @@ KDateTime FreeBusy::dtEnd() const
 }
 
 Period::List FreeBusy::busyPeriods() const
+{
+  Period::List res;
+
+  foreach ( const FreeBusyPeriod &p, d->mBusyPeriods ) {
+    res << p;
+  }
+
+  return res;
+}
+
+FreeBusyPeriod::List FreeBusy::fullBusyPeriods() const
 {
   return d->mBusyPeriods;
 }
@@ -206,6 +250,14 @@ void FreeBusy::sortList()
 }
 
 void FreeBusy::addPeriods( const Period::List &list )
+{
+  foreach ( const Period &p, list ) {
+    d->mBusyPeriods << FreeBusyPeriod(p);
+  }
+  sortList();
+}
+
+void FreeBusy::addPeriods( const FreeBusyPeriod::List &list )
 {
   d->mBusyPeriods += list;
   sortList();
@@ -213,13 +265,13 @@ void FreeBusy::addPeriods( const Period::List &list )
 
 void FreeBusy::addPeriod( const KDateTime &start, const KDateTime &end )
 {
-  d->mBusyPeriods.append( Period( start, end ) );
+  d->mBusyPeriods.append( FreeBusyPeriod( start, end ) );
   sortList();
 }
 
 void FreeBusy::addPeriod( const KDateTime &start, const Duration &duration )
 {
-  d->mBusyPeriods.append( Period( start, duration ) );
+  d->mBusyPeriods.append( FreeBusyPeriod( start, duration ) );
   sortList();
 }
 
@@ -251,6 +303,22 @@ void FreeBusy::shiftTimes( const KDateTime::Spec &oldSpec,
   }
 }
 
+FreeBusy &FreeBusy::operator=( const FreeBusy &other )
+{
+  IncidenceBase::operator=( other );
+  d->init( *other.d );
+  return *this;
+}
+
+bool FreeBusy::operator==( const FreeBusy &freebusy ) const
+{
+  return
+    static_cast<const IncidenceBase &>( *this ) == static_cast<const IncidenceBase &>( freebusy ) &&
+    dtEnd() == freebusy.dtEnd() &&
+    d->mCalendar == freebusy.d->mCalendar &&
+    d->mBusyPeriods == freebusy.d->mBusyPeriods;
+}
+
 //@cond PRIVATE
 bool FreeBusy::Private::addLocalPeriod( FreeBusy *fb,
                                         const KDateTime &eventStart,
@@ -281,7 +349,7 @@ bool FreeBusy::Private::addLocalPeriod( FreeBusy *fb,
     tmpEnd = eventEnd;
   }
 
-  Period p( tmpStart, tmpEnd );
+  FreeBusyPeriod p( tmpStart, tmpEnd );
   mBusyPeriods.append( p );
 
   return true;
