@@ -271,7 +271,8 @@ bool ICalTimeZone::update( const ICalTimeZone &other )
     return false;
   }
 
-  setData( other.data()->clone(), other.source() );
+  KTimeZoneData* otherData = other.data() ? other.data()->clone() : 0;
+  setData( otherData, other.source() );
   return true;
 }
 
@@ -552,10 +553,10 @@ ICalTimeZoneData::ICalTimeZoneData( const KTimeZoneData &rhs,
               }
             } else {
               if ( date.dayOfWeek() != dayOfWeek ||
-                   ( rule & WEEKDAY_OF_MONTH ) &&
-                   ( day - 1 ) / 7 + 1 != nthFromStart ||
-                   ( rule & LAST_WEEKDAY_OF_MONTH ) &&
-                   ( daysInMonth - day ) / 7 + 1 != nthFromEnd ) {
+                   ( ( rule & WEEKDAY_OF_MONTH ) &&
+                     ( day - 1 ) / 7 + 1 != nthFromStart ) ||
+                   ( ( rule & LAST_WEEKDAY_OF_MONTH ) &&
+                     ( daysInMonth - day ) / 7 + 1 != nthFromEnd ) ) {
                 break;
               }
             }
@@ -624,6 +625,10 @@ ICalTimeZoneData::~ICalTimeZoneData()
 
 ICalTimeZoneData &ICalTimeZoneData::operator=( const ICalTimeZoneData &rhs )
 {
+  // check for self assignment
+  if ( &rhs == this )
+    return *this;
+
   KTimeZoneData::operator=( rhs );
   d->location = rhs.d->location;
   d->url = rhs.d->url;
@@ -878,7 +883,7 @@ ICalTimeZone ICalTimeZoneSource::parse( icaltimezone *tz )
    * This is both easier and provides more complete information than
    * extracting already parsed data from icaltimezone.
    */
-  return parse( icaltimezone_get_component( tz ) );
+  return tz ? parse( icaltimezone_get_component( tz ) ) : ICalTimeZone();
 }
 
 //@cond PRIVATE
@@ -916,8 +921,8 @@ QList<QDateTime> ICalTimeZoneSourcePrivate::parsePhase( icalcomponent *c,
       QByteArray tzname = icalproperty_get_tzname( p );
       // Outlook (2000) places "Standard Time" and "Daylight Time" in the TZNAME
       // strings, which is totally useless. So ignore those.
-      if ( !daylight && tzname == "Standard Time" ||
-           daylight && tzname == "Daylight Time" ) {
+      if ( ( !daylight && tzname == "Standard Time" ) ||
+           ( daylight && tzname == "Daylight Time" ) ) {
         break;
       }
       if ( !abbrevs.contains( tzname ) ) {
