@@ -30,11 +30,11 @@
 
 #include "kresources/idmapper.h"
 
+#include <kconfiggroup.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kurl.h>
 #include <kstandarddirs.h>
-#include <kconfiggroup.h>
+#include <kurl.h>
 
 #include <QtCore/QDateTime>
 #include <QtCore/QDataStream>
@@ -201,8 +201,7 @@ void ResourceCached::readConfig( const KConfigGroup &group )
 void ResourceCached::setupSaveTimer()
 {
   if ( d->mSavePolicy == SaveInterval ) {
-    kDebug(5800) << "ResourceCached::setSavePolicy(): start save timer (interval"
-              << d->mSaveInterval << "minutes).";
+    kDebug() << "start save timer (interval " << d->mSaveInterval << "mins)";
     d->mSaveTimer.start( d->mSaveInterval * 60 * 1000 ); // n minutes
   } else {
     d->mSaveTimer.stop();
@@ -212,8 +211,7 @@ void ResourceCached::setupSaveTimer()
 void ResourceCached::setupReloadTimer()
 {
   if ( d->mReloadPolicy == ReloadInterval ) {
-    kDebug(5800) << "ResourceCached::setSavePolicy(): start reload timer (interval"
-                 << d->mReloadInterval << "minutes)";
+    kDebug() << "start reload timer (interval " << d->mReloadInterval << "mins)";
     d->mReloadTimer.start( d->mReloadInterval * 60 * 1000 ); // n minutes
   } else {
     d->mReloadTimer.stop();
@@ -240,7 +238,7 @@ bool ResourceCached::addEvent( Event *event )
 // probably not really efficient, but...it works for now.
 bool ResourceCached::deleteEvent( Event *event )
 {
-  kDebug(5800) << "ResourceCached::deleteEvent";
+  kDebug();
 
   return d->mCalendar.deleteEvent( event );
 }
@@ -322,7 +320,7 @@ Todo::List ResourceCached::rawTodosForDate( const QDate &date )
 
 bool ResourceCached::addJournal( Journal *journal )
 {
-  kDebug(5800) << "Adding Journal on" << journal->dtStart().toString();
+  kDebug() << "Adding Journal on" << journal->dtStart().toString();
 
   return d->mCalendar.addJournal( journal );
 }
@@ -349,8 +347,6 @@ Alarm::List ResourceCached::alarmsTo( const KDateTime &to )
 
 Alarm::List ResourceCached::alarms( const KDateTime &from, const KDateTime &to )
 {
-//  kDebug(5800) << "ResourceCached::alarms(" << from.toString() << "-" << to.toString() << ")";
-
   return d->mCalendar.alarms( from, to );
 }
 
@@ -388,13 +384,13 @@ void ResourceCached::clearChanges()
 
 bool ResourceCached::load( CacheAction action )
 {
-  kDebug(5800) << "Loading resource" << resourceName();
+  kDebug() << resourceName();
 
   setReceivedLoadError( false );
 
   bool success = true;
   if ( !isOpen() ) {
-    success = open();
+    success = open(); //krazy:exclude=syscalls open is a class method
   }
   if ( success ) {
     bool update = false;
@@ -427,7 +423,7 @@ bool ResourceCached::load( CacheAction action )
     }
   }
 
-  kDebug(5800) << "Done loading resource" << resourceName();
+  kDebug() << "Done loading resource" << resourceName();
 
   return success;
 }
@@ -458,12 +454,15 @@ bool ResourceCached::loadFromCache()
 
 bool ResourceCached::save( CacheAction action, Incidence *incidence )
 {
+  if ( !incidence && ( d->mSavePolicy == SaveAlways || d->mSavePolicy == SaveDelayed ) ) {
+    d->mSaveTimer.stop();   // in case it's called manually while save is pending
+  }
   d->mSavePending = false;
   if ( saveInhibited() ) {
     return true;
   }
   if ( !readOnly() ) {
-    kDebug(5800) << "Save resource" << resourceName();
+    kDebug() << "Save resource" << resourceName();
 
     setReceivedSaveError( false );
 
@@ -488,7 +487,7 @@ bool ResourceCached::save( CacheAction action, Incidence *incidence )
     return success;
   } else {
     // Read-only, just don't save...
-    kDebug(5800) << "Don't save read-only resource" << resourceName();
+    kDebug() << "Don't save read-only resource" << resourceName();
     return true;
   }
 }
@@ -506,7 +505,7 @@ bool ResourceCached::doSave( bool syncCache, Incidence *incidence )
 
 void ResourceCached::saveToCache()
 {
-  kDebug(5800) << "ResourceCached::saveToCache():" << cacheFile();
+  kDebug() << cacheFile();
 
   setIdMapperIdentifier();
   d->mIdMapper.save();
@@ -660,10 +659,7 @@ void ResourceCached::loadChangesCache()
 
 void ResourceCached::calendarIncidenceAdded( Incidence *i )
 {
-#if 1
-  kDebug(5800) << "ResourceCached::calendarIncidenceAdded():"
-            << i->uid();
-#endif
+  kDebug() << i->uid();
 
   QMap<Incidence *,bool>::ConstIterator it;
   it = d->mAddedIncidences.find( i );
@@ -676,10 +672,7 @@ void ResourceCached::calendarIncidenceAdded( Incidence *i )
 
 void ResourceCached::calendarIncidenceChanged( Incidence *i )
 {
-#if 1
-  kDebug(5800) << "ResourceCached::calendarIncidenceChanged():"
-            << i->uid();
-#endif
+  kDebug() << i->uid();
 
   QMap<Incidence *,bool>::ConstIterator it;
   it = d->mChangedIncidences.find( i );
@@ -693,10 +686,7 @@ void ResourceCached::calendarIncidenceChanged( Incidence *i )
 
 void ResourceCached::calendarIncidenceDeleted( Incidence *i )
 {
-#if 1
-  kDebug(5800) << "ResourceCached::calendarIncidenceDeleted():"
-            << i->uid();
-#endif
+  kDebug() << i->uid();
 
   QMap<Incidence *,bool>::ConstIterator it;
   it = d->mDeletedIncidences.find( i );
@@ -806,7 +796,7 @@ void ResourceCached::slotReload()
     return;
   }
 
-  kDebug(5800) << "ResourceCached::slotReload()";
+  kDebug();
 
   load( SyncCache );
 }
@@ -817,7 +807,7 @@ void ResourceCached::slotSave()
     return;
   }
 
-  kDebug(5800) << "ResourceCached::slotSave()";
+  kDebug();
 
   save( SyncCache );
 }
@@ -825,12 +815,12 @@ void ResourceCached::slotSave()
 void ResourceCached::checkForAutomaticSave()
 {
   if ( d->mSavePolicy == SaveAlways )  {
-    kDebug(5800) << "ResourceCached::checkForAutomaticSave(): save now";
+    kDebug() << "save now";
     d->mSavePending = true;
     d->mSaveTimer.setSingleShot( true );
     d->mSaveTimer.start( 1 * 1000 ); // 1 second
   } else if ( d->mSavePolicy == SaveDelayed ) {
-    kDebug(5800) << "ResourceCached::checkForAutomaticSave(): save delayed";
+    kDebug() << "save delayed";
     d->mSavePending = true;
     d->mSaveTimer.setSingleShot( true );
     d->mSaveTimer.start( 15 * 1000 ); // 15 seconds
@@ -883,7 +873,7 @@ void ResourceCached::doClose()
 
 bool ResourceCached::doOpen()
 {
-  kDebug(5800) << "Opening resource" << resourceName();
+  kDebug() << "Opening resource" << resourceName();
   return true;
 }
 
